@@ -184,7 +184,7 @@ def correlation_heatmap(df,columns,**kwargs):
     corr.columns = ['x', 'y', 'value']
     
     # get the heatmap
-    fig = dsp.heatmap(
+    fig = heatmap(
         x=corr['x'],
         y=corr['y'],
         value=corr['value'],**kwargs
